unit OptnDlg;

{
1997 Mar 01 - Add compressed/uncompressed size option - NT specific
1997 May 18 - Add font and PieChart colour options
1997 Jun 14 - Add option to enable/disable Folder right-click menu item
1997 Oct 26 - Add "count of files" as the units option
1997 Nov 15 - Add "display free space" option
1998 Jun 11 - Add repeated scan timer option
}

interface

uses
  SysUtils, Windows, Messages, Classes, Graphics, Controls,
  StdCtrls, ExtCtrls, Forms, ComCtrls, PieChart, Dialogs, MultiColour, Spin;

type
  // putting the type definitions here allows sharing of data types
  // between the main form and this options dialog
  Tdisplay_mode = (show_actual, show_allocated, show_slack);
  Tdisplay_units = (show_bytes, show_KB, show_MB, show_count);
  Tdisplay_compressed = (disabled, show_compressed, show_uncompressed);

type
  TOptionsDialog = class(TForm)
    Button1: TButton;
    Button2: TButton;
    PageControl1: TPageControl;
    SpaceSheet: TTabSheet;
    RadioGroup1: TRadioGroup;
    btnActual: TRadioButton;
    btnAllocated: TRadioButton;
    Label1: TLabel;
    btnSlack: TRadioButton;
    UnitsSheet: TTabSheet;
    RadioGroup2: TRadioGroup;
    btnBytes: TRadioButton;
    btnKB: TRadioButton;
    btnMB: TRadioButton;
    Label2: TLabel;
    CompressionSheet: TTabSheet;
    Label3: TLabel;
    RadioGroup3: TRadioGroup;
    btnCompressed: TRadioButton;
    btnUncompressed: TRadioButton;
    DisplaySheet: TTabSheet;
    FontDialog1: TFontDialog;
    Panel1: TPanel;
    btnPieFont: TButton;
    Panel2: TPanel;
    btnListBoxFont: TButton;
    ListBox1: TListBox;
    PieChart1: TPieChart;
    ColorDialog1: TColorDialog;
    Label4: TLabel;
    btnRevert: TButton;
    RightClickSheet: TTabSheet;
    Label5: TLabel;
    RadioGroup4: TRadioGroup;
    chkRightClick: TCheckBox;
    FreeDiskSheet: TTabSheet;
    RadioGroup5: TRadioGroup;
    chkShowFreeDisk: TCheckBox;
    Label6: TLabel;
    btnCount: TRadioButton;
    Label7: TLabel;
    Label8: TLabel;
    TabSheetTimer: TTabSheet;
    Label9: TLabel;
    GroupBox1: TGroupBox;
    CheckBoxRepeatedScan: TCheckBox;
    SpinEditScanInterval: TSpinEdit;
    Label10: TLabel;
    procedure Button1Click(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure btnPieFontClick(Sender: TObject);
    procedure btnListBoxFontClick(Sender: TObject);
    procedure PieChart1DblClick(Sender: TObject);
    procedure btnRevertClick(Sender: TObject);
    procedure chkRightClickClick(Sender: TObject);
    procedure chkShowFreeDiskClick(Sender: TObject);
    procedure CheckBoxRepeatedScanClick(Sender: TObject);
    procedure SpinEditScanIntervalChange(Sender: TObject);
  private
    pie_data_list: TStringList;
  public
    { Public declarations }
    display_mode: Tdisplay_mode;        // variables to set initial options
    display_units: Tdisplay_units;      // and recover any changes
    display_compressed: Tdisplay_compressed;
    piechart_font: TFont;
    listbox_font: TFont;
    piechart_colours: string;
    folder_right_click_enabled: boolean;
    display_free_disk_enabled: boolean;
    repeated_scan: boolean;
    scan_interval: integer;
  end;

var
  OptionsDialog: TOptionsDialog;


implementation

{$R *.DFM}

procedure TOptionsDialog.FormCreate(Sender: TObject);
begin
  pie_data_list := TStringList.Create;
end;

procedure TOptionsDialog.FormDestroy(Sender: TObject);
begin
  pie_data_list.Free;
end;

procedure TOptionsDialog.FormShow(Sender: TObject);
var
  i: integer;
begin
  // on showing this dialog, ensure the buttons are set according
  // to the options that the main program is currently using
  btnAllocated.Checked := False;
  btnSlack.Checked := False;
  btnActual.Checked := False;
  case display_mode of
       show_actual: btnActual.Checked := True;
    show_allocated: btnAllocated.Checked := True;
        show_slack: btnSlack.Checked := True;
  end;
  btnBytes.Checked := False;
  btnKB.Checked := False;
  btnMB.Checked := False;
  btnCount.Checked := False;
  case display_units of
     show_bytes: btnBytes.Checked := True;
        show_KB: btnKB.Checked := True;
        show_MB: btnMB.Checked := True;
     show_count: btnCount.Checked := True;
  end;
  case display_compressed of
    disabled:
      begin
      btnUncompressed.Checked := True;
      btnUncompressed.Enabled := False;
      btnCompressed.Enabled := False;
      end;
    show_compressed: btnCompressed.Checked := True;
    show_uncompressed: btnUncompressed.Checked := True;
  end;
  ListBox1.Font := listbox_font;
  PieChart1.Font := piechart_font;

  PieChart1.Colours := piechart_colours;
  pie_data_list.Clear;
  for i := 0 to PieChart1.NumColours - 1 do
    pie_data_list.AddObject (IntToStr (20 - i) + '   Colour' + IntToStr (i),
                  Pointer (i));
  PieChart1.SetDataAndLabels (pie_data_list);

  chkRightClick.Checked := folder_right_click_enabled;
  chkShowFreeDisk.Checked := display_free_disk_enabled;
  CheckBoxRepeatedScan.Checked := repeated_scan;
  SpinEditScanInterval.Value := scan_interval;
end;

procedure TOptionsDialog.Button1Click(Sender: TObject);
begin
  // code for the OK button being clicked, decode the radio
  // buttons into the enuerated type variables
  if btnAllocated.Checked
  then display_mode := show_allocated
  else if btnSlack.Checked
       then display_mode := show_slack
       else display_mode := show_actual;

  if btnBytes.Checked
  then display_units := show_bytes
  else if btnKB.Checked
       then display_units := show_KB
       else if btnMB.Checked
            then display_units := show_MB
            else display_units := show_count;

  if display_compressed <> disabled then
    if btnCompressed.Checked
    then display_compressed := show_compressed
    else display_compressed := show_uncompressed;

  if display_free_disk_enabled then
    begin
    display_mode := show_allocated;
    end;
end;

procedure TOptionsDialog.btnPieFontClick(Sender: TObject);
begin
  FontDialog1.Font := PieChart1.Font;
  if FontDialog1.Execute then PieChart1.Font := FontDialog1.Font;
  piechart_font := PieChart1.Font;
  ActiveControl := Button1;
end;

procedure TOptionsDialog.btnListBoxFontClick(Sender: TObject);
begin
  FontDialog1.Font := ListBox1.Font;
  if FontDialog1.Execute then ListBox1.Font := FontDialog1.Font;
  listbox_font := ListBox1.Font;
  ActiveControl := Button1;
end;

procedure TOptionsDialog.PieChart1DblClick(Sender: TObject);
var
  colour_number: integer;
begin
  colour_number := Integer (PieChart1.ClickedObject);
  ColorDialog1.Color := PieChart1.ColourArray [colour_number];
  if ColorDialog1.Execute then
    begin
    PieChart1.ColourArray [colour_number] := ColorDialog1.Color;
    piechart_colours := PieChart1.Colours;
    PieChart1.Invalidate;
    end;
end;

procedure TOptionsDialog.btnRevertClick(Sender: TObject);
begin
  PieChart1.Colours := '$E0E0FF,$E0FFFF,$E0FFE0,$FFFFE0,$FFE0E0,$FFE0FF';
  PieChart1.Invalidate;
  piechart_colours := PieChart1.Colours;
end;

procedure TOptionsDialog.chkRightClickClick(Sender: TObject);
begin
  folder_right_click_enabled := chkRightClick.Checked;
end;

procedure TOptionsDialog.chkShowFreeDiskClick(Sender: TObject);
begin
  display_free_disk_enabled := chkShowFreeDisk.Checked;
end;

procedure TOptionsDialog.CheckBoxRepeatedScanClick(Sender: TObject);
begin
  repeated_scan := CheckBoxRepeatedScan.Checked;
end;

procedure TOptionsDialog.SpinEditScanIntervalChange(Sender: TObject);
begin
  scan_interval := SpinEditScanInterval.Value;
end;

end.

